@@ -5,10 +5,7 @@ Module implementing CutetubeWindows.
 """
 from PyQt4.QtGui import *
 from PyQt4.QtCore import *
-try:
-    from PyQt4.QtMaemo5 import QMaemo5InformationBox
-except:
-    pass
+from PyQt4.QtMaemo5 import QMaemo5InformationBox
 from Ui_cutetubewindows import Ui_CutetubeWindows
 
 import videoinfowindow
@@ -16,6 +13,7 @@ import customwidgets
 import youtubeservice
 import cutetubedialogs
 from cutetubeconfig import GeneralSettings
+from cutetubelog import CutetubeLog
 from videoplaybackwindow import VideoPlaybackWindow
 
 class CutetubeWindows(QMainWindow, Ui_CutetubeWindows):
@@ -237,11 +235,14 @@ class CutetubeWindows(QMainWindow, Ui_CutetubeWindows):
             checkBox = self.listWidget.itemWidget(item).checkBox
             checkBox.toggle()
             if checkBox.isChecked():
-                self.pencilList.append(self.listWidget.row(item))
-                self.actionPencilQueue.setVisible(True)
-                self.actionPencilDownloads.setVisible(True)
-                self.actionPencilPlaylist.setVisible(True)
-                self.actionPencilFavourites.setVisible(True)
+                try:
+                    self.pencilList.append(self.listWidget.row(item))
+                    self.actionPencilQueue.setVisible(True)
+                    self.actionPencilDownloads.setVisible(True)
+                    self.actionPencilPlaylist.setVisible(True)
+                    self.actionPencilFavourites.setVisible(True)
+                except Exception, e:
+                    CutetubeLog.logException(e.message)
             else:
                 self.pencilList.remove(self.listWidget.row(item))
                 if len(self.pencilList) == 0:
@@ -635,12 +636,12 @@ class RelatedVideosWindow(CutetubeWindows):
         self.connect(self.yt, SIGNAL("dataLoaded(PyQt_PyObject)"), self.addVideo)
         self.connect(self.yt, SIGNAL("feedCompleted(bool)"), self.toggleBusy)        
         self.connect(self.listWidget.verticalScrollBar(), SIGNAL("valueChanged(int)"), self.getMoreResults)
-        self.loadData(self.video.media.title.text)
+        self.loadData()
 
     def loadData(self):
         try:
             self.yt.start()
-            QMaemo5InformationBox.information(self, "Showing related videos for \'%s\'" % unicode(self.video, "utf-8"))
+            QMaemo5InformationBox.information(self, "Showing related videos for \'%s\'" % unicode(self.video.media.title.text, "utf-8"))
         except:
             try:
                 QMaemo5InformationBox.information(self, "Unable to connect to YouTube, please try again")
@@ -1376,16 +1377,16 @@ class DownloadsWindow(CutetubeWindows):
         row = youtubeservice.YouTubeVideoDownloader.taskQueue.index(currentTask)
         item = self.listWidget.item(row)
         widget = self.listWidget.itemWidget(item)
-        if widget.speedLabel.text() != "completed":
-            try:
+        try:
+            if widget.speedLabel.text() != "completed":
                 widget.progressBar.setValue(int(currentTask.progress*100))
                 widget.speedLabel.setText("d/l speed: %.2f KB/s" % currentTask.speed)
                 if currentTask.progress  == 1.0:
                     QMaemo5InformationBox.information(self,  "Download of \'%s\' is completed" % unicode(currentTask.getTitle(), "utf-8"))
                     widget.speedLabel.setText("completed")
                     self.filterDownloads(self.filterGroup.checkedAction())
-            except AttributeError:
-                pass
+        except AttributeError:
+            pass
             
     def updateTaskStatus(self,  task = youtubeservice.YouTubeVideoDownloader.currentTask):
         try:
@@ -1470,4 +1471,3 @@ class CommentsWindow(CutetubeWindows):
         Overrides the method in ChannelWindow.
         """
         pass
-
