@@ -17,14 +17,11 @@ class VideoPlaybackWindow(Phonon.VideoPlayer):
     Provides playback of YouTube videos.
     """
     def __init__(self, parent, video = None, playlist = None):
+        cutetubeLog.logInfo("Launching video player")
         Phonon.VideoPlayer.__init__(self, parent)
         self.setWindowFlags(Qt.Window)
         self.resize(800, 480)
-        try:
-            self.setAttribute(Qt.WA_Maemo5StackedWindow)
-            self.setAttribute(Qt.WA_Maemo5LandscapeOrientation, True)
-        except:
-            pass
+        self.setAttribute(Qt.WA_Maemo5StackedWindow)
         self.video = video
         self.playlist = playlist
         self.toolBar = QToolBar(self)
