@@ -6,10 +6,6 @@ Module providing access to the YouTube API and downloading of videos.
 from __future__ import with_statement
 from PyQt4.QtCore import *
 from PyQt4.QtGui import *
-try:
-    from PyQt4.QtMaemo5 import QMaemo5InformationBox
-except:
-    pass
 import urllib2
 import urllib
 from cgi import parse_qs
@@ -20,6 +16,7 @@ import shutil
 import gdata.youtube.service
 import gdata.service
 from cutetubeconfig import *
+from cutetubelog import CutetubeLog
 
 class YouTubeDataService(object):
     """
@@ -50,14 +47,20 @@ class YouTubeDataService(object):
         YouTubeDataService.ytService.email = unicode(YouTubeAPISettings.userDict[username][0], "utf-8")
         YouTubeDataService.ytService.password = unicode(YouTubeAPISettings.userDict[username][1], "utf-8")
         try:
+            CutetubeLog.logInfo("Attempting to sign in to YouTube account: %s" % username)
             YouTubeDataService.ytService.ProgrammaticLogin()
             YouTubeDataService.currentUser = username
+            CutetubeLog.logInfo("Signed in to YouTube account: %s" % username)
         except:
-            # Some users have reported authentication issues. Using the username in place of the email address may work.
-            YouTubeDataService.ytService.email = unicode(username, "utf-8")
-            YouTubeDataService.ytService.password = unicode(YouTubeAPISettings.userDict[username][1], "utf-8")
-            YouTubeDataService.ytService.ProgrammaticLogin()
-            YouTubeDataService.currentUser = username
+            try:
+                # Some users have reported authentication issues. Using the username in place of the email address may work.
+                YouTubeDataService.ytService.email = unicode(username, "utf-8")
+                YouTubeDataService.ytService.password = unicode(YouTubeAPISettings.userDict[username][1], "utf-8")
+                YouTubeDataService.ytService.ProgrammaticLogin()
+                YouTubeDataService.currentUser = username
+                CutetubeLog.logInfo("Signed in to YouTube account: %s" % username)
+            except Exception, e:
+                CutetubeLog.logException("Unable to sign in to YouTube account:")
         
     @staticmethod
     def addComment(comment, videoId):
@@ -186,30 +189,34 @@ class YouTubeDataService(object):
         Much of the code for this method is borrowed from youtube.py 
         of MediaBox.
         """
-        videoUrl = ""       
-        playerUrl = video.media.player.url.split("&")[0]
-        html = urllib.urlopen(playerUrl).read()
-        html = "".join(html.split())
-        formats = {}
-        pos = html.find("\",\"fmt_url_map\":\"")
-        if (pos != -1):
-            pos2 = html.find("\"", pos + 17)
-            fmt_map = urllib.unquote(html[pos + 17:pos2]) + ","
-            parts = fmt_map.split("|")
-            key = parts[0]
-            for p in parts[1:]:
-                idx = p.rfind(",")
-                value = p[:idx].replace("\\/", "/")
-                formats[int(key)] = value
-                key = p[idx + 1:]
-            
-        formatList = [22, 35, 34, 18, 17]
-        for format in formatList[formatList.index(videoFormat):]:
-            if videoFormat in formats:
-                videoUrl = formats.get(videoFormat)
+        try:
+            CutetubeLog.logInfo("Retreiving video URL for \'%s\' (id = %s)" % (video.media.title.text, video.media.player.url.split("=") [1].split("&")[0]))
+            videoUrl = ""       
+            playerUrl = video.media.player.url.split("&")[0]
+            html = urllib.urlopen(playerUrl).read()
+            html = "".join(html.split())
+            formats = {}
+            pos = html.find("\",\"fmt_url_map\":\"")
+            if (pos != -1):
+                pos2 = html.find("\"", pos + 17)
+                fmt_map = urllib.unquote(html[pos + 17:pos2]) + ","
+                parts = fmt_map.split("|")
+                key = parts[0]
+                for p in parts[1:]:
+                    idx = p.rfind(",")
+                    value = p[:idx].replace("\\/", "/")
+                    formats[int(key)] = value
+                    key = p[idx + 1:]
+                
+            formatList = [22, 35, 34, 18, 17]
+            for format in formatList[formatList.index(videoFormat):]:
+                if videoFormat in formats:
+                    videoUrl = formats.get(videoFormat)
+                    break
                 break
-            break
-        return videoUrl
+            return videoUrl
+        except Exception, e:
+            CutetubeLog.logException("Unable to retrieve video URL for \'%s\' (id = %s)" % (video.media.title.text, video.media.player.url.split("=") [1].split("&")[0]))
 
 class YouTubeVideoFeed(QThread):
     """
@@ -228,22 +235,26 @@ class YouTubeVideoFeed(QThread):
         """
         try:
             try:
-                self.ytVideoFeed = YouTubeDataService.ytService.GetYouTubeVideoFeed(("%s?start-index=%s" % (self.videoFeed, unicode(self.results + 1))).encode("utf-8"))
+                self.ytVideoFeed = YouTubeDataService.ytService.GetYouTubeVideoFeed(("%s?start-index=%d" % (self.videoFeed, self.results + 1)).encode("utf-8"))
             except:
-                self.ytVideoFeed = YouTubeDataService.ytService.GetYouTubeVideoFeed(("%s&start-index=%s" % (self.videoFeed, unicode(self.results + 1))).encode("utf-8"))
-        except gdata.service.RequestError:
+                self.ytVideoFeed = YouTubeDataService.ytService.GetYouTubeVideoFeed(("%s&start-index=%d" % (self.videoFeed, self.results + 1)).encode("utf-8"))
+        except gdata.service.RequestError, e:
+            CutetubeLog.logException("Unable to retrieve video feed. Trying again")
             try:
-                self.ytVideoFeed = YouTubeDataService.ytService.GetYouTubeVideoFeed(("%s?start-index=%s" % (self.videoFeed, unicode(self.results + 1))).encode("utf-8"))
+                self.ytVideoFeed = YouTubeDataService.ytService.GetYouTubeVideoFeed(("%s?start-index=%d" % (self.videoFeed, self.results + 1)).encode("utf-8"))
             except:
-                self.ytVideoFeed = YouTubeDataService.ytService.GetYouTubeVideoFeed(("%s&start-index=%s" % (self.videoFeed, unicode(self.results + 1))).encode("utf-8"))
+                self.ytVideoFeed = YouTubeDataService.ytService.GetYouTubeVideoFeed(("%s&start-index=%d" % (self.videoFeed, self.results + 1)).encode("utf-8"))
             
     def getVideoData(self):
         for video in self.ytVideoFeed.entry:
-            thumbnail = YouTubeDataService.getVideoThumbnail(video.media.thumbnail[3].url)
-            videoData = (video, thumbnail)
-            self.videoList.append(video)
-            self.emit(SIGNAL("dataLoaded(PyQt_PyObject)"), videoData)
-            self.results += 1
+            try:
+                thumbnail = YouTubeDataService.getVideoThumbnail(video.media.thumbnail[3].url)
+                videoData = (video, thumbnail)
+                self.videoList.append(video)
+                self.emit(SIGNAL("dataLoaded(PyQt_PyObject)"), videoData)
+                self.results += 1
+            except Exception, e:
+                CutetubeLog.logException("Unable to retrieve video entry: \'%s\' (id = %s)" % (video.media.title.text, video.media.player.url.split("=") [1].split("&")[0]))
 
     def run(self):
         self.emit(SIGNAL("feedCompleted(bool)"), True)
@@ -380,13 +391,13 @@ class YouTubeVideoDownloader(object):
         object.__init__(self, parent = None)
         
     @staticmethod
-    def addTask(video, status = VideoDownloadSettings.defaultTaskStatus):
+    def addTask(video):
         """
         Add the video to the download queue. 
         """
         task = DownloadTask(video)
         YouTubeVideoDownloader.taskQueue.append(task)
-        if YouTubeVideoDownloader.currentStatus == "inactive" and status == "queued":
+        if YouTubeVideoDownloader.currentStatus == "inactive" and VideoDownloadSettings.defaultTaskStatus == "queued":
             YouTubeVideoDownloader.run()
             
     @staticmethod
@@ -440,7 +451,7 @@ class YouTubeVideoDownloader(object):
         for task in taskList:
             videoId = unicode(task, "utf-8")
             video = YouTubeDataService.getVideoEntry(videoId)
-            YouTubeVideoDownloader.addTask(video, "paused")
+            YouTubeVideoDownloader.addTask(video)
     
     @staticmethod
     def run():
@@ -480,9 +491,9 @@ class DownloadTask(QThread):
         if self.status != "completed":
             os.remove(self.tempname)
 
-    def __init__(self, video, status = VideoDownloadSettings.defaultTaskStatus):
+    def __init__(self, video):
         QThread.__init__(self,  parent = None)
-        self.status = status
+        self.status = VideoDownloadSettings.defaultTaskStatus
         self.statusChanged = True
         self.video = video
         self.connect(self,  SIGNAL("finished()"),  YouTubeVideoDownloader.run)
@@ -583,16 +594,16 @@ class DownloadTask(QThread):
                 self.emit(SIGNAL("statusChanged()"))
         except urllib.ContentTooShortError, ctse:
             self.status = "failed"
-            print'Missing content from server'
+            CutetubeLog.logException("Missing content from server")
             self.emit(SIGNAL("statusChanged()"))
             
         except IOError, ioe:
-            print 'Error "%s" while downloading "%s"' % (ioe.strerror, self.video.media.title.text)
+            CutetubeLog.logException("Error %s while downloading %s" % (ioe.strerror, self.video.media.title.text))
             self.status = "failed"
             self.emit(SIGNAL("statusChanged()"))
         except Exception, e:
             self.status = "failed"
-            print 'Error: %s' % e.message
+            CutetubeLog.logException("Error: %s" % e.message)
             self.emit(SIGNAL("statusChanged()"))
         
         
